@@ -4,7 +4,7 @@ import sentry_sdk
 from rich.logging import RichHandler
 from rich.console import Console
 
-__all__ = ["log", "get_tokens", "console"]
+__all__ = ["log", "setLogLevel", "get_tokens", "console"]
 
 logging.basicConfig(
     level=logging.INFO,
@@ -19,6 +19,14 @@ sentry_sdk.init(
 )
 
 
+def setLogLevel(level):
+    """
+    Sets the log level of the global logger to the passed level
+    :param level: the log level
+    """
+    logging.getLogger().setLevel(level)
+
+
 def get_tokens():
     """
     Checks if the required API keys for Spotify has been set.
@@ -48,7 +56,7 @@ def get_tokens():
             set SPOTIPY_CLIENT_SECRET=your-spotify-client-secret
 
             Get your credentials at
-                https://developer.spotify.com/my-applications
+                https://developer.spotify.com/dashboard
         """
         )
         return None
